@@ -120,7 +120,7 @@ class PipeboardAuthManager:
         else:
             logger.info("Pipeboard authentication not enabled. Set PIPEBOARD_API_TOKEN environment variable to enable.")
         self.token_info = None
-        self._load_cached_token()
+        # Note: Token caching is disabled to always fetch fresh tokens from Pipeboard
     
     def _get_token_cache_path(self) -> Path:
         """Get the platform-specific path for token cache file"""
@@ -151,6 +151,18 @@ class PipeboardAuthManager:
             with open(cache_path, "r") as f:
                 logger.debug(f"Reading token cache from {cache_path}")
                 data = json.load(f)
+                
+                # Validate the cached data structure
+                required_fields = ["access_token"]
+                if not all(field in data for field in required_fields):
+                    logger.warning("Cached token data is missing required fields")
+                    return False
+                
+                # Check if the token looks valid (basic format check)
+                if not data.get("access_token") or len(data["access_token"]) < 20:
+                    logger.warning("Cached token appears malformed")
+                    return False
+                
                 self.token_info = TokenInfo.deserialize(data)
                 
                 # Log token details (partial token for security)
@@ -159,7 +171,25 @@ class PipeboardAuthManager:
                 
                 # Check if token is expired
                 if self.token_info.is_expired():
-                    logger.info("Cached token is expired")
+                    logger.info("Cached token is expired, removing cache file")
+                    # Remove the expired cache file
+                    try:
+                        cache_path.unlink()
+                        logger.info(f"Removed expired token cache: {cache_path}")
+                    except Exception as e:
+                        logger.warning(f"Could not remove expired cache file: {e}")
+                    self.token_info = None
+                    return False
+                
+                # Additional validation: check if token is too old (more than 60 days)
+                current_time = int(time.time())
+                if self.token_info.created_at and (current_time - self.token_info.created_at) > (60 * 24 * 3600):
+                    logger.warning("Cached token is too old (more than 60 days), removing cache file")
+                    try:
+                        cache_path.unlink()
+                        logger.info(f"Removed old token cache: {cache_path}")
+                    except Exception as e:
+                        logger.warning(f"Could not remove old cache file: {e}")
                     self.token_info = None
                     return False
                 
@@ -174,9 +204,21 @@ class PipeboardAuthManager:
                 logger.debug(f"Raw cache file content (first 100 chars): {raw_content[:100]}")
             except Exception as e2:
                 logger.error(f"Could not read raw cache file: {e2}")
+            # If there's any error reading the cache, try to remove the corrupted file
+            try:
+                cache_path.unlink()
+                logger.info(f"Removed corrupted token cache: {cache_path}")
+            except Exception as cleanup_error:
+                logger.warning(f"Could not remove corrupted cache file: {cleanup_error}")
             return False
         except Exception as e:
             logger.error(f"Error loading cached token: {e}")
+            # If there's any error reading the cache, try to remove the corrupted file
+            try:
+                cache_path.unlink()
+                logger.info(f"Removed corrupted token cache: {cache_path}")
+            except Exception as cleanup_error:
+                logger.warning(f"Could not remove corrupted cache file: {cleanup_error}")
             return False
     
     def _save_token_to_cache(self) -> None:
@@ -278,18 +320,7 @@ class PipeboardAuthManager:
             logger.error("Please set PIPEBOARD_API_TOKEN environment variable")
             return None
             
-        # Check if we already have a valid token
-        if not force_refresh and self.token_info and not self.token_info.is_expired():
-            logger.debug("Using existing valid token")
-            return self.token_info.access_token
-            
-        # If we have a token but it's expired, log that information
-        if not force_refresh and self.token_info and self.token_info.is_expired():
-            logger.error("TOKEN VALIDATION FAILED: Existing token is expired")
-            if self.token_info.expires_at:
-                logger.error(f"Token expiration time: {self.token_info.expires_at}")
-        
-        logger.info(f"Getting new token (force_refresh={force_refresh})")
+        logger.info("Getting fresh token from Pipeboard (caching disabled)")
         
         # If force refresh or no token/expired token, get a new one from Pipeboard
         try:
@@ -356,8 +387,7 @@ class PipeboardAuthManager:
                 token_type=data.get("token_type", "bearer")
             )
             
-            # Save to cache
-            self._save_token_to_cache()
+            # Note: Token caching is disabled
             
             masked_token = self.token_info.access_token[:10] + "..." + self.token_info.access_token[-5:] if self.token_info.access_token else "None"
             logger.info(f"Successfully retrieved access token: {masked_token}")
